==> libgnomedb-0.8.101.tar.gz: libgnomedb-0.8.101/libgnomedb/gnome-db-dsn-config.h <==
/* GNOME DB library
 * Copyright (C) 1999-2002 The GNOME Foundation
 *
 * AUTHORS:
 *      Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_dsn_config_h__)
#  define __gnome_db_dsn_config_h__

#include <libgda/gda-config.h>
#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_DSN_CONFIG            (gnome_db_dsn_config_get_type())
#define GNOME_DB_DSN_CONFIG(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_DSN_CONFIG, GnomeDbDsnConfig))
#define GNOME_DB_DSN_CONFIG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GNOME_DB_TYPE_DSN_CONFIG, GnomeDbDsnConfigClass))
#define GNOME_DB_IS_DSN_CONFIG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_DSN_CONFIG))
#define GNOME_DB_IS_DSN_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_DSN_CONFIG))

typedef struct _GnomeDbDsnConfig        GnomeDbDsnConfig;
typedef struct _GnomeDbDsnConfigClass   GnomeDbDsnConfigClass;
typedef struct _GnomeDbDsnConfigPrivate GnomeDbDsnConfigPrivate;

struct _GnomeDbDsnConfig {
	GtkVBox box;
	GnomeDbDsnConfigPrivate *priv;
};

struct _GnomeDbDsnConfigClass {
	GtkVBoxClass parent_class;
};

GType      gnome_db_dsn_config_get_type (void);
GtkWidget *gnome_db_dsn_config_new (void);

G_END_DECLS

#endif

==> libgnomedb-0.12.0.tar.gz: libgnomedb-0.12.0/libgnomedb/gnome-db-dsn-config.h <==
/* GNOME DB library
 * Copyright (C) 1999-2002 The GNOME Foundation
 *
 * AUTHORS:
 *      Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_dsn_config_h__)
#  define __gnome_db_dsn_config_h__

#include <libgda/gda-config.h>
#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_DSN_CONFIG            (gnome_db_dsn_config_get_type())
#define GNOME_DB_DSN_CONFIG(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_DSN_CONFIG, GnomeDbDsnConfig))
#define GNOME_DB_DSN_CONFIG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GNOME_DB_TYPE_DSN_CONFIG, GnomeDbDsnConfigClass))
#define GNOME_DB_IS_DSN_CONFIG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_DSN_CONFIG))
#define GNOME_DB_IS_DSN_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_DSN_CONFIG))

typedef struct _GnomeDbDsnConfig        GnomeDbDsnConfig;
typedef struct _GnomeDbDsnConfigClass   GnomeDbDsnConfigClass;
typedef struct _GnomeDbDsnConfigPrivate GnomeDbDsnConfigPrivate;

struct _GnomeDbDsnConfig {
	GtkVBox box;
	GnomeDbDsnConfigPrivate *priv;
};

struct _GnomeDbDsnConfigClass {
	GtkVBoxClass parent_class;
};

GType              gnome_db_dsn_config_get_type (void);
GtkWidget         *gnome_db_dsn_config_new (void);

GdaDataSourceInfo *gnome_db_dsn_config_get_info (GnomeDbDsnConfig *config);
void               gnome_db_dsn_config_set_info (GnomeDbDsnConfig *config,
						 const GdaDataSourceInfo *dsn_info);

G_END_DECLS

#endif
